==> v1.3.1.tar.gz: syncthingtray-1.3.1/tray/translations/syncthingtray_en_US.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>QtGui::DevView</name>
    <message>
        <location filename="../gui/devview.cpp" line="59"/>
        <source>Copy value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/devview.cpp" line="65"/>
        <source>Copy name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/devview.cpp" line="68"/>
        <source>Copy ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/devview.cpp" line="74"/>
        <source>Resume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/devview.cpp" line="79"/>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::DirView</name>
    <message>
        <location filename="../gui/dirview.cpp" line="75"/>
        <source>Copy value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="81"/>
        <source>Copy label/ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="84"/>
        <source>Copy path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="89"/>
        <source>Rescan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="94"/>
        <source>Resume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="99"/>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="103"/>
        <source>Open in file browser</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::DownloadView</name>
    <message>
        <location filename="../gui/downloadview.cpp" line="65"/>
        <source>Copy value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/downloadview.cpp" line="70"/>
        <source>Copy label/ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/downloadview.cpp" line="74"/>
        <source>Open in file browser</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::TrayIcon</name>
    <message>
        <location filename="../gui/trayicon.cpp" line="54"/>
        <source>Open Syncthing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="58"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="62"/>
        <source>Rescan all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="66"/>
        <source>Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="70"/>
        <source>Show internal errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="75"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="80"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="214"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="234"/>
        <source>Launcher error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="250"/>
        <source>Syncthing notification - click to dismiss</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="280"/>
        <source>Syncthing device wants to connect - click for web UI</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="296"/>
        <source>New Syncthing directory - click for web UI</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="175"/>
        <source>Disconnected from Syncthing</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::TrayWidget</name>
    <message>
        <location filename="../gui/traywidget.ui" line="6"/>
        <source>Syncthing Tray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="99"/>
        <location filename="../gui/traywidget.cpp" line="337"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="58"/>
        <location filename="../gui/traywidget.cpp" line="462"/>
        <source>Connect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="72"/>
        <location filename="../gui/traywidget.cpp" line="838"/>
        <location filename="../gui/traywidget.cpp" line="880"/>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="113"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="127"/>
        <source>Open Syncthing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="289"/>
        <source>In</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="296"/>
        <source>Incoming traffic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="228"/>
        <location filename="../gui/traywidget.ui" line="248"/>
        <location filename="../gui/traywidget.ui" line="299"/>
        <location filename="../gui/traywidget.ui" line="319"/>
        <source>unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="218"/>
        <source>Global</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="225"/>
        <source>Global overall statistics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="235"/>
        <source>Local</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="245"/>
        <source>Local overall statistics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="306"/>
        <source>Out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="316"/>
        <source>Outgoing traffic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="356"/>
        <source>Click to show &lt;i&gt;new&lt;/i&gt; notifications&lt;br&gt;
For &lt;i&gt;all&lt;/i&gt; notifications, checkout the log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="360"/>
        <location filename="../gui/traywidget.cpp" line="157"/>
        <location filename="../gui/traywidget.cpp" line="380"/>
        <source>New notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="391"/>
        <source>Directories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="424"/>
        <source>Devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="457"/>
        <source>Downloads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="486"/>
        <source>Recent changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="522"/>
        <source>Show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="532"/>
        <source>Dismiss</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="129"/>
        <source>View own device ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="134"/>
        <source>Restart Syncthing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="139"/>
        <source>Show Syncthing log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="144"/>
        <source>Rescan all directories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="151"/>
        <source>Connection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="173"/>
        <source>Show internal errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="188"/>
        <source>Quit Syncthing Tray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="437"/>
        <source>Do you really want to restart Syncthing?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="463"/>
        <source>Not connected to Syncthing, click to connect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="468"/>
        <source>Unable to establish connection to Syncthing.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="478"/>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="479"/>
        <source>Syncthing is running, click to pause all devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="484"/>
        <source>Continue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="485"/>
        <source>At least one device is paused, click to resume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="608"/>
        <source>The specified connection configuration &lt;em&gt;%1&lt;/em&gt; is not defined and hence ignored.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="643"/>
        <source>The directory &lt;i&gt;%1&lt;/i&gt; does not exist on the local machine.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="654"/>
        <source>The containing directory &lt;i&gt;%1&lt;/i&gt; does not exist on the local machine.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="697"/>
        <source>Copy path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="701"/>
        <source>Copy device ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="704"/>
        <source>Copy directory ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="834"/>
        <location filename="../gui/traywidget.cpp" line="874"/>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="835"/>
        <source>Stop Syncthing instance launched via tray icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="839"/>
        <source>Start Syncthing with the built-in launcher configured in the settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../application/main.cpp" line="60"/>
        <source>Unable to </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="93"/>
        <source>The system tray is (currently) not available. You could open the tray menu as a regular window using the --windowed flag, though.It is also possible to start Syncthing Tray with --wait to wait until the system tray becomes available instead of showing this message.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="120"/>
        <source>The Qt libraries have not been built with tray icon support. You could open the tray menu as a regular window using the -w flag, though.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> v1.6.0.tar.gz: syncthingtray-1.6.0/tray/translations/syncthingtray_en_US.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>QtGui::DevView</name>
    <message>
        <location filename="../gui/devview.cpp" line="60"/>
        <source>Copy value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/devview.cpp" line="66"/>
        <source>Copy name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/devview.cpp" line="69"/>
        <source>Copy ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/devview.cpp" line="75"/>
        <source>Resume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/devview.cpp" line="80"/>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::DirView</name>
    <message>
        <location filename="../gui/dirview.cpp" line="77"/>
        <source>Copy value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="83"/>
        <source>Copy label/ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="86"/>
        <source>Copy path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="91"/>
        <source>Rescan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="96"/>
        <source>Resume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="101"/>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="105"/>
        <source>Open in file browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="109"/>
        <source>Browse remote files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="111"/>
        <source>Show/edit ignore patterns</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::DownloadView</name>
    <message>
        <location filename="../gui/downloadview.cpp" line="65"/>
        <source>Copy value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/downloadview.cpp" line="70"/>
        <source>Copy label/ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/downloadview.cpp" line="74"/>
        <source>Open in file browser</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::TrayIcon</name>
    <message>
        <location filename="../gui/trayicon.cpp" line="54"/>
        <source>Open Syncthing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="58"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="62"/>
        <source>Rescan all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="66"/>
        <source>Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="70"/>
        <source>Show internal errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="75"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="80"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="214"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="234"/>
        <source>Launcher error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="250"/>
        <source>Syncthing notification - click to dismiss</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="280"/>
        <source>Syncthing device wants to connect - click for web UI</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="296"/>
        <source>New Syncthing folder - click for web UI</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="175"/>
        <source>Disconnected from Syncthing</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::TrayWidget</name>
    <message>
        <location filename="../gui/traywidget.ui" line="6"/>
        <source>Syncthing Tray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="99"/>
        <location filename="../gui/traywidget.cpp" line="350"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="58"/>
        <location filename="../gui/traywidget.cpp" line="479"/>
        <source>Connect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="72"/>
        <location filename="../gui/traywidget.cpp" line="899"/>
        <location filename="../gui/traywidget.cpp" line="941"/>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="113"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="127"/>
        <source>Open Syncthing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="289"/>
        <source>In</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="296"/>
        <source>Incoming traffic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="228"/>
        <location filename="../gui/traywidget.ui" line="248"/>
        <location filename="../gui/traywidget.ui" line="299"/>
        <location filename="../gui/traywidget.ui" line="319"/>
        <source>unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="218"/>
        <source>Global</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="225"/>
        <source>Global overall statistics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="235"/>
        <source>Local</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="245"/>
        <source>Local overall statistics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="306"/>
        <source>Out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="316"/>
        <source>Outgoing traffic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="350"/>
        <source>Click to show &lt;i&gt;new&lt;/i&gt; notifications&lt;br&gt;
For &lt;i&gt;all&lt;/i&gt; notifications, checkout the log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="357"/>
        <location filename="../gui/traywidget.cpp" line="160"/>
        <location filename="../gui/traywidget.cpp" line="390"/>
        <source>New notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="388"/>
        <source>Folders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="421"/>
        <source>Devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="454"/>
        <source>Downloads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="483"/>
        <source>Recent changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="519"/>
        <source>Show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="529"/>
        <source>Dismiss</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="132"/>
        <source>View own device ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="137"/>
        <source>Restart Syncthing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="142"/>
        <source>Show Syncthing log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="147"/>
        <source>Rescan all folders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="154"/>
        <source>Connection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="176"/>
        <source>Show internal errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="191"/>
        <source>Quit Syncthing Tray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="447"/>
        <source>Do you really want to restart Syncthing?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="474"/>
        <source>Connecting …</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="475"/>
        <source>Establishing connection to Syncthing …</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="480"/>
        <source>Not connected to Syncthing, click to connect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="485"/>
        <source>Unable to establish connection to Syncthing.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="493"/>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="494"/>
        <source>Syncthing is running, click to pause all devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="499"/>
        <source>Continue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="500"/>
        <source>At least one device is paused, click to resume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="625"/>
        <source>The specified connection configuration &lt;em&gt;%1&lt;/em&gt; is not defined and hence ignored.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="696"/>
        <source>The folder &lt;i&gt;%1&lt;/i&gt; does not exist on the local machine.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="707"/>
        <source>The containing folder &lt;i&gt;%1&lt;/i&gt; does not exist on the local machine.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="760"/>
        <source>Copy path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="764"/>
        <source>Copy device ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="767"/>
        <source>Copy folder ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="895"/>
        <location filename="../gui/traywidget.cpp" line="935"/>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="896"/>
        <source>Stop Syncthing instance launched via tray icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="900"/>
        <source>Start Syncthing with the built-in launcher configured in the settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../application/main.cpp" line="66"/>
        <source>Unable to </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="101"/>
        <source>The system tray is (currently) not available. You could open the tray menu as a regular window using the --windowed flag, though.It is also possible to start Syncthing Tray with --wait to wait until the system tray becomes available instead of showing this message.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="128"/>
        <source>The Qt libraries have not been built with tray icon support. You could open the tray menu as a regular window using the -w flag, though.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
